@@ -121,7 +121,7 @@ class BotBase(object):
             begin.click()
             logger.info("Clicked begin experiment button.")
             WebDriverWait(self.driver, 10).until(lambda d: len(d.window_handles) == 2)
-            self.driver.switch_to_window(self.driver.window_handles[-1])
+            self.driver.switch_to.window(self.driver.window_handles[-1])
             self.driver.set_window_size(1024, 768)
             logger.info("Switched to experiment popup.")
             consent = WebDriverWait(self.driver, 10).until(
@@ -172,7 +172,7 @@ class BotBase(object):
             self.complete_questionnaire()
             feedback.click()
             logger.info("Clicked submit questionnaire button.")
-            self.driver.switch_to_window(self.driver.window_handles[0])
+            self.driver.switch_to.window(self.driver.window_handles[0])
             self.driver.set_window_size(1024, 768)
             logger.info("Switched back to initial window.")
             return True
