@@ -26,6 +26,7 @@ from dallinger import registration
 from dallinger.config import get_config
 from dallinger.heroku.tools import HerokuApp
 from dallinger.heroku.tools import HerokuLocalWrapper
+from dallinger.utils import connect_to_redis
 from dallinger.utils import dallinger_package_path
 from dallinger.utils import ensure_directory
 from dallinger.utils import get_base_url
@@ -79,8 +80,7 @@ class ExperimentFileSource(object):
 
     @property
     def size(self):
-        """Combined size of all files, accounting for exclusions.
-        """
+        """Combined size of all files, accounting for exclusions."""
         return sum([os.path.getsize(path) for path in self._walk()])
 
     def selective_copy_to(self, destination):
@@ -127,8 +127,7 @@ class ExperimentFileSource(object):
 
 
 class ExplicitFileSource(object):
-    """Add files that are explicitly requested by the experimenter with a hook function.
-    """
+    """Add files that are explicitly requested by the experimenter with a hook function."""
 
     def __init__(self, root_dir="."):
         self.root = root_dir
@@ -175,14 +174,12 @@ class ExplicitFileSource(object):
 
     @property
     def size(self):
-        """Combined size of all files, accounting for exclusions.
-        """
+        """Combined size of all files, accounting for exclusions."""
         return sum([os.path.getsize(path) for path in self.files])
 
     def selective_copy_to(self, destination):
-        """Write files from the source directory to another directory, skipping
-        files excluded by the general exclusion_policy, plus any files
-        ignored by git configuration.
+        """Write files declared in extra_files from the source directory
+        to another directory.
         """
         for from_path, to_path in self._get_mapping(destination):
             target_folder = os.path.dirname(to_path)
@@ -476,15 +473,17 @@ def deploy_sandbox_shared_setup(
     heroku_app.set_multiple(**heroku_config)
 
     # Wait for Redis database to be ready.
-    log("Waiting for Redis...")
+    log("Waiting for Redis (this can take a couple minutes)...", nl=False)
     ready = False
     while not ready:
         try:
-            r = redis.from_url(heroku_app.redis_url)
+            r = connect_to_redis(url=heroku_app.redis_url)
             r.set("foo", "bar")
             ready = True
+            log("\n✓ connected at {}".format(heroku_app.redis_url), chevrons=False)
         except (ValueError, redis.exceptions.ConnectionError):
             time.sleep(2)
+            log(".", chevrons=False, nl=False)
 
     log("Saving the URL of the postgres database...")
     config.extend({"database_url": heroku_app.db_url})
@@ -697,7 +696,8 @@ class DebugDeployment(HerokuLocalDeployment):
         self.out.log("Experiment dashboard: {}".format(url))
         self.out.log(
             "Dashboard user: {} password: {}".format(
-                config.get("dashboard_user"), config.get("dashboard_password"),
+                config.get("dashboard_user"),
+                config.get("dashboard_password"),
             )
         )
 
@@ -706,7 +706,9 @@ class DebugDeployment(HerokuLocalDeployment):
         self.out.log("Opening dashboard")
         parsed = list(urlparse(url))
         parsed[1] = "{}:{}@{}".format(
-            config.get("dashboard_user"), config.get("dashboard_password"), parsed[1],
+            config.get("dashboard_user"),
+            config.get("dashboard_password"),
+            parsed[1],
         )
         open_browser(urlunparse(parsed))
 
